Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RWLockerFactory ¶
type RWLockerFactory[K comparable] struct { // ReadOptimised will make RLocker and rsync perform much faster, // at the expense of having a global read locking when a read lock is made before a write locking. // This cause a side effect that acquiring write locks for other keys will hang until the read operation is done. // // In the end, this shortcut leads to a whopping <350% increase in read operation speed, // while also supporting write operations as well. // However, it causes only a 0.17% decrease in write speed performance. ReadOptimised bool // contains filtered or unexported fields }
func (*RWLockerFactory[K]) RWLocker ¶
func (l *RWLockerFactory[K]) RWLocker(key K) RWLocker
Click to show internal directories.
Click to hide internal directories.